@@ -12,7 +12,7 @@ Usage::
     session_client: IoTDataPlaneClient = session.client("iot-data")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, IO, TYPE_CHECKING, Type, Union
+from typing import Any, Dict, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_iot_data.type_defs import (
     DeleteThingShadowResponseTypeDef,
@@ -71,13 +71,13 @@ class IoTDataPlaneClient:
         [Client.get_thing_shadow documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
         """
 
-    def publish(self, topic: str, qos: int = None, payload: Union[bytes, IO] = None) -> None:
+    def publish(self, topic: str, qos: int = None, payload: bytes = None) -> None:
         """
         [Client.publish documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/iot-data.html#IoTDataPlane.Client.publish)
         """
 
     def update_thing_shadow(
-        self, thingName: str, payload: Union[bytes, IO]
+        self, thingName: str, payload: bytes
     ) -> UpdateThingShadowResponseTypeDef:
         """
         [Client.update_thing_shadow documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
