@@ -8,7 +8,6 @@ Usage::
     data: DeleteThingShadowResponseTypeDef = {...}
 """
 import sys
-from typing import IO, Union
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -22,14 +21,12 @@ __all__ = (
     "UpdateThingShadowResponseTypeDef",
 )
 
-DeleteThingShadowResponseTypeDef = TypedDict(
-    "DeleteThingShadowResponseTypeDef", {"payload": Union[bytes, IO]}
-)
+DeleteThingShadowResponseTypeDef = TypedDict("DeleteThingShadowResponseTypeDef", {"payload": bytes})
 
 GetThingShadowResponseTypeDef = TypedDict(
-    "GetThingShadowResponseTypeDef", {"payload": Union[bytes, IO]}, total=False
+    "GetThingShadowResponseTypeDef", {"payload": bytes}, total=False
 )
 
 UpdateThingShadowResponseTypeDef = TypedDict(
-    "UpdateThingShadowResponseTypeDef", {"payload": Union[bytes, IO]}, total=False
+    "UpdateThingShadowResponseTypeDef", {"payload": bytes}, total=False
 )
